==> porchestrator-0.4.0.tar.gz: porchestrator-0.4.0/README.md <==
<h1 align="center">
 <a>
  <img src="https://github.com/j-raghavan/orchestrator/blob/main/assets/orchestrator.png?raw=True" width="60" height="50" alt="Orchestrator" style="vertical-align: middle;"> Orchestrator
  </a>
</h1>

<p align="center">
  <a href="https://opensource.org/licenses/MIT">
    <img src="https://img.shields.io/badge/License-MIT-yellow.svg" alt="License: MIT">
  </a>
  <a href="https://python.org">
    <img src="https://img.shields.io/badge/python-3.7+-blue.svg" alt="Python: 3.7+">
  </a>
  <a href="https://pypi.org/project/orchestrator">
    <img src="https://badge.fury.io/py/orchestrator.svg" alt="PyPI version">
  </a>
</p>

Orchestrator is a Python package that simplifies task orchestrations. It is built on top of the `prefect` package and aims to provide an easy-to-use interface for `prefect` by utilizing a YAML configuration file. This project offers a highly streamlined approach to task management and coordination.


## Key Features

- Simplifies task orchestrations
- Built on top of the `prefect` package
- Utilizes a YAML configuration file
- Streamlined approach to task management and coordination



## Getting Started

### Installation


# Quick Start

# Contributing
We welcome contributions to Orchestrator! Please see our Contributing Guide for more details on how to get started.


# License
This project is licensed under the MIT License - see the LICENSE file for details.


# Acknowledgments
Orchestrator is inspired by the excellent work done by the Prefect team. We are grateful for their 
contributions to the open-source community. Prefect is licensed under the Apache License 2.0. 
The full text of their license can be found [here](https://github.com/PrefectHQ/prefect/blob/eb367aff04cb2f94313ec215909f3595ef3acf09/LICENSE).

==> porchestrator-0.5.0.tar.gz: porchestrator-0.5.0/README.md <==
<h1 align="center">
 <a>
  <img src="https://github.com/j-raghavan/orchestrator/blob/main/assets/orchestrator.png?raw=True" width="60" height="50" alt="Orchestrator" style="vertical-align: middle;"> Orchestrator
  </a>
</h1>

<p align="center">
  <a href="https://opensource.org/licenses/MIT">
    <img src="https://img.shields.io/badge/License-MIT-yellow.svg" alt="License: MIT">
  </a>
  <a href="https://python.org">
    <img src="https://img.shields.io/badge/python-3.7+-blue.svg" alt="Python: 3.7+">
  </a>
  <a href="https://pypi.org/project/porchestrator">
    <img src="https://badge.fury.io/py/porchestrator.svg" alt="PyPI version">
  </a>
</p>

Orchestrator is a Python package that simplifies task orchestrations. It is built on top of the `prefect` package and aims to provide an easy-to-use interface for `prefect` by utilizing a YAML configuration file. This project offers a highly streamlined approach to task management and coordination.


## Key Features

- Simplifies task orchestrations
- Built on top of the `prefect` package
- Utilizes a YAML configuration file
- Streamlined approach to task management and coordination



## Getting Started


## Installation

To install the `Orchestrator` package, you can use pip:

```shell
pip install porchestrator
```

Alternatively, you can install it from source by cloning the repository and running the following command:

```shell
python setup.py install
```

Make sure you have Python 3.7 or above installed before proceeding with the installation.


# Quick Start

# Contributing
We welcome contributions to Orchestrator! Please see our Contributing Guide for more details on how to get started.


# License
This project is licensed under the MIT License - see the LICENSE file for details.


# Acknowledgments
Orchestrator is inspired by the excellent work done by the Prefect team. We are grateful for their 
contributions to the open-source community. Prefect is licensed under the Apache License 2.0. 
The full text of their license can be found [here](https://github.com/PrefectHQ/prefect/blob/eb367aff04cb2f94313ec215909f3595ef3acf09/LICENSE).
